@@ -269,6 +269,55 @@ class KrakenAPI(object):
 
         return dt, unixtime
 
+    @crl_sleep
+    @callratelimiter('public')
+    def get_system_status(self):
+        """Get system status.
+
+        Return the Kraken system status.
+
+        Returns
+        -------
+        status : str
+            The systems status. Possible status values include:
+                online (operational, full trading available)
+                cancel_only (existing orders are cancelable, but new orders
+                    cannot be created)
+                post_only (existing orders are cancelable, and only new post
+                    limit orders can be submitted)
+                limit_only (existing orders are cancelable, and only new limit
+                    orders can be submitted)
+                maintenance (system is offline for maintenance)
+
+        timestamp : pandas._libs.tslib.Timestamp
+            The server's datetime.
+
+        Raises
+        ------
+        HTTPError
+            An HTTP error occurred.
+
+        KrakenAPIError
+            A kraken.com API error occurred.
+
+        CallRateLimitError
+            The call rate limiter blocked the query.
+
+        """
+
+        # query
+        res = self.api.query_public('SystemStatus')
+
+        # check for error
+        if len(res['error']) > 0:
+            raise KrakenAPIError(res['error'])
+
+        # extract results
+        status = res['result']['status']
+        timestamp = pd.to_datetime(res['result']['timestamp'])
+
+        return status, timestamp
+
     @crl_sleep
     @callratelimiter('public')
     def get_asset_info(self, info=None, aclass=None, asset=None):
@@ -550,6 +599,8 @@ class KrakenAPI(object):
             ohlc['dtime'] = pd.to_datetime(ohlc.time, unit='s')
             ohlc.sort_values('dtime', ascending=ascending, inplace=True)
             ohlc.set_index('dtime', inplace=True)
+            freq = str(interval) + 'T' if ascending else str(-interval) + 'T'
+            ohlc.index.freq = freq
 
             # dtypes
             for col in ['open', 'high', 'low', 'close', 'vwap', 'volume']:
@@ -1846,7 +1897,7 @@ class KrakenAPI(object):
             User reference id.  32-bit signed number.
 
         validate : bool, optional (default=True)
-            Validate inputs only.  Do not submit order (default).
+            Validate inputs only. Do not submit order (default).
 
         optional closing order to add to system when order gets filled:
             close[ordertype] = order type
